GPI
===

The Ganga Public Interface provides a wrapper around the internals of the Python implementation to provide safety and
to increase ease-of-use.

:doc:`classes`

:doc:`functions`

:doc:`plugins`
